.. qpoint documentation master file, created by
   sphinx-quickstart on Thu Aug  3 15:55:43 2017.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

QPoint Documentation
====================

.. automodule:: qpoint
    :undoc-members:
    :show-inheritance:

.. toctree::
   :maxdepth: 2
   :caption: Contents:

   quickstart
   api

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
